@@ -12,7 +12,7 @@ set -o pipefail
 
 # match qt version prefix. E.g 5 --> 5.15.2, 5.12 --> 5.12.10
 export QT_VER_PREFIX="6"
-export LIBTORRENT_BRANCH="RC_2_0"
+export LIBTORRENT_BRANCH="RC_1_2"
 
 rm -f /etc/apt/sources.list.d/*.list*
 # Ubuntu mirror for local building
@@ -225,18 +225,19 @@ cat config.summary
 cmake --build . --parallel
 cmake --install .
 
+# Remove qt-wayland until next release: https://bugreports.qt.io/browse/QTBUG-104318
 # qt-wayland
-if [ ! -f "/usr/src/qtwayland-${qt_ver}/.unpack_ok" ]; then
-  qtwayland_url="https://download.qt.io/official_releases/qt/${qt_major_ver}/${qt_ver}/submodules/qtwayland-everywhere-src-${qt_ver}.tar.xz"
-  retry curl -kSL --compressed "${qtwayland_url}" \| tar Jxf - -C "/usr/src/qtwayland-${qt_ver}" --strip-components 1
-  touch "/usr/src/qtwayland-${qt_ver}/.unpack_ok"
-fi
-cd "/usr/src/qtwayland-${qt_ver}"
-rm -fr CMakeCache.txt
-"${QT_BASE_DIR}/bin/qt-configure-module" .
-cat config.summary
-cmake --build . --parallel
-cmake --install .
+# if [ ! -f "/usr/src/qtwayland-${qt_ver}/.unpack_ok" ]; then
+#   qtwayland_url="https://download.qt.io/official_releases/qt/${qt_major_ver}/${qt_ver}/submodules/qtwayland-everywhere-src-${qt_ver}.tar.xz"
+#   retry curl -kSL --compressed "${qtwayland_url}" \| tar Jxf - -C "/usr/src/qtwayland-${qt_ver}" --strip-components 1
+#   touch "/usr/src/qtwayland-${qt_ver}/.unpack_ok"
+# fi
+# cd "/usr/src/qtwayland-${qt_ver}"
+# rm -fr CMakeCache.txt
+# "${QT_BASE_DIR}/bin/qt-configure-module" .
+# cat config.summary
+# cmake --build . --parallel
+# cmake --install .
 
 # install qt6gtk2 for better look
 if [ ! -d "/usr/src/qt6gtk2/" ]; then
@@ -371,10 +372,10 @@ extra_plugins=(
   sqldrivers
   styles
   tls
-  wayland-decoration-client
-  wayland-graphics-integration-client
-  wayland-graphics-integration-server
-  wayland-shell-integration
+  # wayland-decoration-client
+  # wayland-graphics-integration-client
+  # wayland-graphics-integration-server
+  # wayland-shell-integration
   xcbglintegrations
 )
 exclude_libs=(
@@ -412,6 +413,9 @@ exclude_libs=(
   libmircore.so.1
   libmirprotobuf.so.3
   libmount.so.1
+  libpango-1.0.so.0
+  libpangocairo-1.0.so.0
+  libpangoft2-1.0.so.0
   libpixman-1.so.0
   libprotobuf-lite.so.9
   libselinux.so.1
