@@ -112,9 +112,9 @@ void AppController::preferencesAction()
     data["torrent_changed_tmm_enabled"] = !session->isDisableAutoTMMWhenCategoryChanged();
     data["save_path_changed_tmm_enabled"] = !session->isDisableAutoTMMWhenDefaultSavePathChanged();
     data["category_changed_tmm_enabled"] = !session->isDisableAutoTMMWhenCategorySavePathChanged();
-    data["save_path"] = Utils::Fs::toNativePath(session->defaultSavePath());
-    data["temp_path_enabled"] = session->isTempPathEnabled();
-    data["temp_path"] = Utils::Fs::toNativePath(session->tempPath());
+    data["save_path"] = Utils::Fs::toNativePath(session->savePath());
+    data["temp_path_enabled"] = session->isDownloadPathEnabled();
+    data["temp_path"] = Utils::Fs::toNativePath(session->downloadPath());
     data["export_dir"] = Utils::Fs::toNativePath(session->torrentExportDirectory());
     data["export_dir_fin"] = Utils::Fs::toNativePath(session->finishedTorrentExportDirectory());
 
@@ -153,8 +153,8 @@ void AppController::preferencesAction()
     // Connection
     // Listening Port
     data["listen_port"] = session->port();
+    data["random_port"] = (session->port() == 0);  // deprecated
     data["upnp"] = Net::PortForwarder::instance()->isEnabled();
-    data["random_port"] = session->useRandomPort();
     // Connections Limits
     data["max_connec"] = session->maxConnections();
     data["max_connec_per_torrent"] = session->maxConnectionsPerTorrent();
@@ -200,7 +200,7 @@ void AppController::preferencesAction()
     const QTime end_time = pref->getSchedulerEndTime();
     data["schedule_to_hour"] = end_time.hour();
     data["schedule_to_min"] = end_time.minute();
-    data["scheduler_days"] = pref->getSchedulerDays();
+    data["scheduler_days"] = static_cast<int>(pref->getSchedulerDays());
 
     // Bittorrent
     // Privacy
@@ -264,9 +264,12 @@ void AppController::preferencesAction()
     // Custom HTTP headers
     data["web_ui_use_custom_http_headers_enabled"] = pref->isWebUICustomHTTPHeadersEnabled();
     data["web_ui_custom_http_headers"] = pref->getWebUICustomHTTPHeaders();
+    // Reverse proxy
+    data["web_ui_reverse_proxy_enabled"] = pref->isWebUIReverseProxySupportEnabled();
+    data["web_ui_reverse_proxies_list"] = pref->getWebUITrustedReverseProxiesList();
     // Update my dynamic domain name
     data["dyndns_enabled"] = pref->isDynDNSEnabled();
-    data["dyndns_service"] = pref->getDynDNSService();
+    data["dyndns_service"] = static_cast<int>(pref->getDynDNSService());
     data["dyndns_username"] = pref->getDynDNSUsername();
     data["dyndns_password"] = pref->getDynDNSPassword();
     data["dyndns_domain"] = pref->getDynDomainName();
@@ -291,6 +294,8 @@ void AppController::preferencesAction()
     data["recheck_completed_torrents"] = pref->recheckTorrentsOnCompletion();
     // Resolve peer countries
     data["resolve_peer_countries"] = pref->resolvePeerCountries();
+    // Reannounce to all trackers when ip/port changed
+    data["reannounce_when_address_changed"] = session->isReannounceWhenAddressChangedEnabled();
 
     // libtorrent preferences
     // Async IO threads
@@ -316,6 +321,8 @@ void AppController::preferencesAction()
     data["send_buffer_watermark"] = session->sendBufferWatermark();
     data["send_buffer_low_watermark"] = session->sendBufferLowWatermark();
     data["send_buffer_watermark_factor"] = session->sendBufferWatermarkFactor();
+    // Outgoing connections per second
+    data["connection_speed"] = session->connectionSpeed();
     // Socket listen backlog size
     data["socket_backlog_size"] = session->socketBacklogSize();
     // Outgoing ports
@@ -397,11 +404,11 @@ void AppController::setPreferencesAction()
     if (hasKey("category_changed_tmm_enabled"))
         session->setDisableAutoTMMWhenCategorySavePathChanged(!it.value().toBool());
     if (hasKey("save_path"))
-        session->setDefaultSavePath(it.value().toString());
+        session->setSavePath(it.value().toString());
     if (hasKey("temp_path_enabled"))
-        session->setTempPathEnabled(it.value().toBool());
+        session->setDownloadPathEnabled(it.value().toBool());
     if (hasKey("temp_path"))
-        session->setTempPath(it.value().toString());
+        session->setDownloadPath(it.value().toString());
     if (hasKey("export_dir"))
         session->setTorrentExportDirectory(it.value().toString());
     if (hasKey("export_dir_fin"))
@@ -482,12 +489,16 @@ void AppController::setPreferencesAction()
 
     // Connection
     // Listening Port
-    if (hasKey("listen_port"))
+    if (hasKey("random_port") && it.value().toBool())  // deprecated
+    {
+        session->setPort(0);
+    }
+    else if (hasKey("listen_port"))
+    {
         session->setPort(it.value().toInt());
+    }
     if (hasKey("upnp"))
         Net::PortForwarder::instance()->setEnabled(it.value().toBool());
-    if (hasKey("random_port"))
-        session->setUseRandomPort(it.value().toBool());
     // Connections Limits
     if (hasKey("max_connec"))
         session->setMaxConnections(it.value().toInt());
@@ -526,7 +537,7 @@ void AppController::setPreferencesAction()
     if (hasKey("ip_filter_trackers"))
         session->setTrackerFilteringEnabled(it.value().toBool());
     if (hasKey("banned_IPs"))
-        session->setBannedIPs(it.value().toString().split('\n', QString::SkipEmptyParts));
+        session->setBannedIPs(it.value().toString().split('\n', Qt::SkipEmptyParts));
     if (hasKey("auto_ban_unknown_peer"))
         session->setAutoBanUnknownPeer(it.value().toBool());
     if (hasKey("auto_ban_bt_player_peer"))
@@ -558,7 +569,7 @@ void AppController::setPreferencesAction()
     if (m.contains("schedule_to_hour") && m.contains("schedule_to_min"))
         pref->setSchedulerEndTime(QTime(m["schedule_to_hour"].toInt(), m["schedule_to_min"].toInt()));
     if (hasKey("scheduler_days"))
-        pref->setSchedulerDays(SchedulerDays(it.value().toInt()));
+        pref->setSchedulerDays(static_cast<Scheduler::Days>(it.value().toInt()));
 
     // Bittorrent
     // Privacy
@@ -664,7 +675,7 @@ void AppController::setPreferencesAction()
     if (hasKey("bypass_auth_subnet_whitelist"))
     {
         // recognize new lines and commas as delimiters
-        pref->setWebUiAuthSubnetWhitelist(it.value().toString().split(QRegularExpression("\n|,"), QString::SkipEmptyParts));
+        pref->setWebUiAuthSubnetWhitelist(it.value().toString().split(QRegularExpression("\n|,"), Qt::SkipEmptyParts));
     }
     if (hasKey("web_ui_max_auth_fail_count"))
         pref->setWebUIMaxAuthFailCount(it.value().toInt());
@@ -691,11 +702,16 @@ void AppController::setPreferencesAction()
         pref->setWebUICustomHTTPHeadersEnabled(it.value().toBool());
     if (hasKey("web_ui_custom_http_headers"))
         pref->setWebUICustomHTTPHeaders(it.value().toString());
+    // Reverse proxy
+    if (hasKey("web_ui_reverse_proxy_enabled"))
+        pref->setWebUIReverseProxySupportEnabled(it.value().toBool());
+    if (hasKey("web_ui_reverse_proxies_list"))
+        pref->setWebUITrustedReverseProxiesList(it.value().toString());
     // Update my dynamic domain name
     if (hasKey("dyndns_enabled"))
         pref->setDynDNSEnabled(it.value().toBool());
     if (hasKey("dyndns_service"))
-        pref->setDynDNSService(it.value().toInt());
+        pref->setDynDNSService(static_cast<DNS::Service>(it.value().toInt()));
     if (hasKey("dyndns_username"))
         pref->setDynDNSUsername(it.value().toString());
     if (hasKey("dyndns_password"))
@@ -748,6 +764,9 @@ void AppController::setPreferencesAction()
     // Resolve peer countries
     if (hasKey("resolve_peer_countries"))
         pref->resolvePeerCountries(it.value().toBool());
+    // Reannounce to all trackers when ip/port changed
+    if (hasKey("reannounce_when_address_changed"))
+        session->setReannounceWhenAddressChangedEnabled(it.value().toBool());
 
     // libtorrent preferences
     // Async IO threads
@@ -786,6 +805,9 @@ void AppController::setPreferencesAction()
         session->setSendBufferLowWatermark(it.value().toInt());
     if (hasKey("send_buffer_watermark_factor"))
         session->setSendBufferWatermarkFactor(it.value().toInt());
+    // Outgoing connections per second
+    if (hasKey("connection_speed"))
+        session->setConnectionSpeed(it.value().toInt());
     // Socket listen backlog size
     if (hasKey("socket_backlog_size"))
         session->setSocketBacklogSize(it.value().toInt());
@@ -857,7 +879,7 @@ void AppController::setPreferencesAction()
 
 void AppController::defaultSavePathAction()
 {
-    setResult(BitTorrent::Session::instance()->defaultSavePath());
+    setResult(BitTorrent::Session::instance()->savePath());
 }
 
 void AppController::networkInterfaceListAction()
